@@ -1,19 +1,11 @@
-/***************************************************************************
-                          FilterPMail.cxx  -  Pegasus-Mail import
-                             -------------------
-    begin                : Sat Jan 6 2001
-    copyright            : (C) 2001 by Holger Schurig <holgerschurig@gmx.de>
-                           (C) 2005 by Danny Kukawka <danny.kukawka@web.de>
- ***************************************************************************/
+/*
+  filterpmail.cpp  -  Pegasus-Mail import
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+  SPDX-FileCopyrightText: 2001 Holger Schurig <holgerschurig@gmx.de>
+  SPDX-FileCopyrightText: 2005 Danny Kukawka <danny.kukawka@web.de>
+
+  SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "filterpmail.h"
 #include "mailimporter_debug.h"
@@ -58,7 +50,10 @@ void FilterPMail::importMails(const QString &chosenDir)
     // Count total number of files to be processed
     filterInfo()->addInfoLogEntry(i18n("Counting files..."));
     dir.setPath(mailDir());
-    const QStringList files = dir.entryList(QStringList() << QStringLiteral("*.[cC][nN][mM]") << QStringLiteral("*.[pP][mM][mM]") << QStringLiteral("*.[mM][bB][xX]"), QDir::Files, QDir::Name);
+    const QStringList files =
+        dir.entryList(QStringList() << QStringLiteral("*.[cC][nN][mM]") << QStringLiteral("*.[pP][mM][mM]") << QStringLiteral("*.[mM][bB][xX]"),
+                      QDir::Files,
+                      QDir::Name);
     totalFiles = files.count();
     currentFile = 0;
     qCDebug(MAILIMPORTER_LOG) << "Count is" << totalFiles;
@@ -87,7 +82,7 @@ void FilterPMail::processFiles(const QString &mask, void (FilterPMail::*workFunc
     }
 
     const QStringList files = dir.entryList(QStringList(mask), QDir::Files, QDir::Name);
-    //qCDebug(MAILIMPORTER_LOG) <<"Mask is" << mask <<" count is" << files.count();
+    // qCDebug(MAILIMPORTER_LOG) <<"Mask is" << mask <<" count is" << files.count();
     QStringList::ConstIterator end = files.constEnd();
     for (QStringList::ConstIterator mailFile = files.constBegin(); mailFile != end; ++mailFile) {
         // Notify current file
@@ -168,7 +163,7 @@ void FilterPMail::importMailFolder(const QString &file)
             folder.append(QString::fromLatin1(pmm_head.folder));
         }
         filterInfo()->setTo(folder);
-        filterInfo()->addInfoLogEntry(i18n("Importing %1", QString::fromLatin1("../") + QString::fromLatin1(pmm_head.folder)));
+        filterInfo()->addInfoLogEntry(i18n("Importing %1", QStringLiteral("../") + QString::fromLatin1(pmm_head.folder)));
 
         QByteArray input(MAX_LINE, '\0');
         bool first_msg = true;
@@ -214,9 +209,12 @@ void FilterPMail::importUnixMailFolder(const QString &file)
     } pmg_head;
 
     QFile f;
-    QString folder(QStringLiteral("PegasusMail-Import/")), s(file), separate;
+    QString folder(QStringLiteral("PegasusMail-Import/"));
+    QString s(file);
+    QString separate;
     QByteArray line(MAX_LINE, '\0');
-    int n = 0, l = 0;
+    int n = 0;
+    int l = 0;
 
     /** Get the folder name */
     s.replace(QRegularExpression(QStringLiteral("mbx$")), QStringLiteral("pmg"));
@@ -291,11 +289,7 @@ bool FilterPMail::parseFolderMatrix(const QString &chosendir)
             }
             QString tmpArray[5];
             tmpRead.remove(tmpRead.length() - 2, 2);
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-            QStringList tmpList = QString::fromLatin1(tmpRead).split(QLatin1Char(','), QString::SkipEmptyParts);
-#else
             QStringList tmpList = QString::fromLatin1(tmpRead).split(QLatin1Char(','), Qt::SkipEmptyParts);
-#endif
             int i = 0;
             QStringList::ConstIterator end(tmpList.constEnd());
             for (QStringList::ConstIterator it = tmpList.constBegin(); it != end; ++it, ++i) {
