@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef FILTERMailAppTEST_H
-#define FILTERMailAppTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -20,5 +19,3 @@ private Q_SLOTS:
     void canNotImportDataEmptyPath();
     void canNotImportDataUnknowPath();
 };
-
-#endif // FILTERMailAppTEST_H
